@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.83';
+$VERSION = '0.84';
 
 use constant MINUS_ONE           => -1;
 
@@ -68,7 +68,7 @@ use constant PARENT              => ( __PACKAGE__ =~ m{ (.+?) ::Constants }xms )
 use constant IS_WINDOWS          => $^O eq 'MSWin32' || $^O eq 'MSWin64';
 use constant DELIM_START         => 0; # field id
 use constant DELIM_END           => 1; # field id
-use constant RE_NONFILE          => qr{ [ \n \r < > \* \? ] }xmso;
+use constant RE_NONFILE          => qr{ [ \n \r < > * ? ] }xmso;
 use constant RE_DUMP_ERROR       => qr{Can\'t \s locate \s object \s method \s "first" \s via \s package \s "B::SVOP"}xms;
 use constant COMPILER            => PARENT.'::Compiler'; # The compiler
 use constant COMPILER_SAFE       => COMPILER.'::Safe';   # Safe compiler
@@ -150,9 +150,10 @@ use constant DIGEST_MODS => qw(
    Digest::Perl::MD5
 );
 
-use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (NAME|PARAM|FILTER|SHARE) : /xms;
+use constant RE_PIPE_SPLIT   => qr/ [|] (?:\s+)? (NAME|PARAM|FILTER|SHARE) : /xms;
 use constant RE_FILTER_SPLIT => qr/ \, (?:\s+)? /xms;
-use constant RE_INVALID_CID  => qr{[^A-Za-z_0-9]}xms;
+use constant RE_INVALID_CID  =>
+    qr{[^A-Za-z_0-9]}xms; ## no critic (ProhibitEnumeratedClasses)
 
 use constant DISK_CACHE_MARKER => q{# This file is automatically generated by }
                                .  PARENT
@@ -320,8 +321,8 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.83> of C<Text::Template::Simple::Constants>
-released on C<9 February 2011>.
+This document describes version C<0.84> of C<Text::Template::Simple::Constants>
+released on C<15 November 2011>.
 
 Constants for Text::Template::Simple.
 
@@ -336,7 +337,7 @@ Copyright 2004 - 2011 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.1 or, 
+it under the same terms as Perl itself, either Perl version 5.12.3 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
